guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

137/195: gnu: python-nbval: Move to pyproject-build-system.


From: guix-commits
Subject: 137/195: gnu: python-nbval: Move to pyproject-build-system.
Date: Tue, 15 Oct 2024 03:30:01 -0400 (EDT)

sharlatan pushed a commit to branch python-team-rebased
in repository guix.

commit 4be52fe3893be40a55e6c8369206d432fe578d58
Author: Nicolas Graves <ngraves@ngraves.fr>
AuthorDate: Fri May 10 00:53:26 2024 +0200

    gnu: python-nbval: Move to pyproject-build-system.
    
    * gnu/packages/python-check.scm (python-nbval):
      [build-system]: Move to pyproject-build-system.
      [arguments]: Move <#:phases> check phase replacement into proper
      <#:test-flags>.
    
    Change-Id: I93aa282399eb52636ee5561b5d8fb7bb5b93f9e0
    Signed-off-by: Nicolas Goaziou <mail@nicolasgoaziou.fr>
---
 gnu/packages/python-check.scm | 29 ++++++++++++++---------------
 1 file changed, 14 insertions(+), 15 deletions(-)

diff --git a/gnu/packages/python-check.scm b/gnu/packages/python-check.scm
index 51b39ae759..b7ae55e608 100644
--- a/gnu/packages/python-check.scm
+++ b/gnu/packages/python-check.scm
@@ -1625,22 +1625,21 @@ notebooks.")
        (uri (pypi-uri "nbval" version))
        (sha256
         (base32 "154h6xpf9h6spgg3ax6k79fd40j197ipwnfjmf5rc2kvc2bmgjbp"))))
-    (build-system python-build-system)
+    (build-system pyproject-build-system)
     (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (add-before 'check 'fix-test
-           (lambda _
-             ;; This test fails because of a mismatch in the output of LaTeX
-             ;; equation environments.  Seems OK to skip.
-             (delete-file
-              "tests/ipynb-test-samples/test-latex-pass-correctouput.ipynb")))
-         (replace 'check
-           (lambda* (#:key tests? #:allow-other-keys)
-             (when tests?
-               (invoke "pytest" "-vv"
-                       ;; nbdime forms a dependency cycle
-                       "--ignore=tests/test_nbdime_reporter.py")))))))
+     (list
+      #:test-flags
+      #~(list
+         ;; nbdime forms a dependency cycle
+         "--ignore=tests/test_nbdime_reporter.py")
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-before 'check 'fix-test
+            (lambda _
+              ;; This test fails because of a mismatch in the output of LaTeX
+              ;; equation environments.  Seems OK to skip.
+              (delete-file
+               
"tests/ipynb-test-samples/test-latex-pass-correctouput.ipynb"))))))
     (native-inputs (list python-pytest-cov python-sympy))
     (propagated-inputs
      (list python-coverage



reply via email to

[Prev in Thread] Current Thread [Next in Thread]